Re-exports
pub use address::*;pub use coord::*;pub use coord_hash::*;pub use date_serial::*;pub use error::*;pub use function::*;pub use grid_address::*;pub use range::*;pub use value::*;
Modules
- address
- Sheet-scoped reference helpers shared across the workspace.
- coord
- Compact coordinate representations shared across the engine and bindings.
- coord_
hash - Dedicated hasher for keys built around
crate::Coord/ workbook cell addresses. - date_
serial - Canonical Excel date-serial conversion.
- error
- Excel-style error representation that is both ergonomic now and flexible enough to grow new, data-rich variants later.
- function
- grid_
address - Owned, binding-neutral spreadsheet addresses.
- range
- value