SheetAddressError

Enum SheetAddressError 

#[non_exhaustive]
pub enum SheetAddressError { ZeroIndex, RowOutOfBounds, ColumnOutOfBounds, NonSingleCellRange, RangeOrder, MismatchedSheets, MissingSheetName, UnboundedRange, Coord(CoordError), Parse(A1ParseError), }
Errors that can occur while constructing sheet-scoped references.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ZeroIndex

Encountered a 0 or underflowed 1-based index when converting to 0-based.



RowOutOfBounds

A row exceeded the 1,048,576-row spreadsheet grid.



ColumnOutOfBounds

A column exceeded the 16,384-column spreadsheet grid.



NonSingleCellRange

Attempted to convert a multi-cell range into a cell address.



RangeOrder

Start/end coordinates were not ordered (start <= end).



MismatchedSheets

Attempted to combine references with different sheet locators.



MissingSheetName

Requested operation requires a sheet name but only an id/current was supplied.



UnboundedRange

Attempted to convert an unbounded range into a bounded representation.



Coord(CoordError)

Wrapped CoordError that originated from RelativeCoord.



Parse(A1ParseError)

Wrapped A1ParseError originating from A1 parsing.