parse_excel_datetime_text

Function parse_excel_datetime_text 

pub fn parse_excel_datetime_text(input: &str) -> Option<NaiveDateTime>
Parse an en-US date and time separated by whitespace or an ISO T.

Date and time components use parse_excel_date_text and parse_excel_time_text. T is accepted only after a four-digit-year ISO date. There is no locale parameter, and parsing is independent of the host locale.