Canonical Excel date-serial conversion.
Excel workbooks use either the 1900 or 1904 date system. The 1900 system
also contains a fictitious 1900-02-29 at serial 60. Since chrono cannot
represent that date (or Excel’s display-only 1900-01-00 at serial 0),
calendar conversion and display conversion are intentionally separate.
Structs
- Excel
Date Parts - Calendar fields rendered by Excel, including display-only dates that
cannot be represented by
chrono::NaiveDate.
Functions
- date_
to_ serial_ for - Convert a date to an Excel serial in the selected date system.
- datetime_
to_ serial - Compatibility wrapper for the historical, implicit Excel-1900 API.
- datetime_
to_ serial_ for - Convert a datetime to an Excel serial in the selected date system.
- max_
excel_ serial_ for - Return the final whole-day serial supported by Excel’s calendar.
- parse_
excel_ date_ text - Parse date text using Formualizer’s deterministic en-US spreadsheet convention.
- parse_
excel_ datetime_ text - Parse an en-US date and time separated by whitespace or an ISO
T. - parse_
excel_ datetime_ text_ to_ serial_ for - Parse spreadsheet date, time, or datetime text and return its serial.
- parse_
excel_ time_ text - Parse time text using fixed 24-hour or English AM/PM formats.
- serial_
to_ datetime - Compatibility wrapper for the historical, implicit Excel-1900 API.
- time_
to_ fraction - Convert a time to its fractional-day representation.
- try_
serial_ to_ date_ for - Convert an Excel serial to a representable
chronodate. - try_
serial_ to_ datetime_ for - Convert an Excel serial to a representable
chronodatetime. - try_
serial_ to_ display_ date_ parts_ for - Return the date fields Excel displays for a serial.
- validate_
excel_ serial - Validate an Excel serial before converting it to a calendar value.